oceanum package — oceanum 0.1.0 documentation

# oceanum package

## Subpackages

- oceanum.datamesh package
  - Submodules
  - oceanum.datamesh.catalog module
  - oceanum.datamesh.connection module
  - oceanum.datamesh.datasource module
  - oceanum.datamesh.query module
  - Module contents
- oceanum.utils package
  - Submodules
  - oceanum.utils.response module
  - Module contents

## Submodules

## oceanum.cli module

Console script for oceanum library.

## Module contents

Top-level package for oceanum.